UncheckedCell

Struct UncheckedCell 

pub struct UncheckedCell<T> {
    value: UnsafeCell<MaybeUninit<T>>,
}
A datatype with interior mutability, which can be uninitialized via [MaybeUninit] When the cargo feature debug-checks is enabled, this type also checks for double initialization and uninitialized access.

Fields

value: UnsafeCell<MaybeUninit<T>>

Implementations

Source

impl<T> UncheckedCell<T>

pub const fn new() -> Self

Constructor; creates a new UncheckedCell

pub unsafe fn init(&self, value: T)

Initialize the inner value

Safety

The caller must guarantee the following:

  • That this method has never been called before and will never be called again
  • That at the time of calling this method, no references or pointers to this data exist
  • While this method is being called, no other CPU is working with the given data
pub unsafe fn get(&self) -> &T

Get a reference to the inner value

Safety

The caller must guarantee the following:

  • That this value’s init method has already been called before
  • That at this method’s entire execution time, no mutable references or pointers to this data exist or will exist